# Problema inventado

Para plantear un problema inventado, cree en su repositorio de control de versiones personal una carpeta `inventados`. Esta será la carpeta donde el profesor buscará por problemas inventados. En la carpeta `inventados` extraiga el contenido del archivo `.zip` a una subcarpeta para el problema a proponer. Si extrajo en una carpeta fuera de su repositorio, muévala a la carpeta `inventados` de su repositorio de control de versiones. Dele un nombre a la carpeta de su problema propuesto, por ejemplo, si el contexto del problema es sobre una carrera de kayaks puede llamarla `carrera_kayaks` o preferiblemente en inglés, algo como `kayak_race`.

Escriba el enunciado del problema en español en este archivo (`readme.es.md`). Cambie el título por uno alusivo al contexto del problema. Conviene contextualizar el enunciado con detalle. Use listas, tablas, imágenes, secciones de código para hacer el problema más claro. Asegúrese de comprender el formato Markdown. Puede usar un editor que soporte Markdown, como Atom, o revise si su editor favorito tiene una extensión. También puede instalar extensiones de "Markdown preview" para su navegador y arrastrarle el archivo `problem.es.md` para visualizar su conversión a HTML.

Una vez que haya escrito el enunciado, cree casos de prueba en parejas de archivos numerados `input###.txt` y `output###.txt`. El archivo `.zip` contiene 10 archivos vacíos para crear casos de prueba, pero puede agregar más si necesita.

1. Escriba primero casos de prueba pequeños que ayuden a comprender lo que debe hacer el programa.
2. Luego escriba casos triviales, por ejemplo, todos los valores de la entrada `input###.txt` en cero, y lo que se espera que el programa produzca en el correspondiente `output###.txt`.
3. Finalmente escriba casos de prueba con valores extremos, fuera de rango, negativos, o incorrectos (ej. textos en lugar de números), dependiendo de cuánto desee que se valide la entrada.
4. Puede crear casos de prueba extensos una vez que se tenga implementada una solución, como se verá adelante.

Provea dentro del enunciado (este archivo) al menos un ejemplo de un caso de prueba, normalmente el primero de ellos. Use secciones de código como las que se muestran a continuación.

**Ejemplo de entrada**:

	Copie el contenido del archivo input000.txt aquí.
	Mantenga la indentación para que sea texto literal.

**Ejemplo de salida**:

	Copie el contenido del archivo output000.txt aquí.
	Mantenga la indentación para que sea texto literal.

Explique el ejemplo de entrada y salida, o al menos, asegúrese de que el enunciado sea suficiente para comprender qué es cada trozo de la entrada y salida. Si es necesario, explique condiciones excepcionales a las que el programa debe enfrentarse. Por ejemplo: "Si el número no es válido el programa debe imprimir `invalid data` para alertar a los usuarios".


## Provea una solución

Una vez escrito el enunciado y casos de prueba, proceda a solucionar el problema. Diseñe una solución (por ejemplo, un algoritmo). Luego impleméntela en el archivo correspondiente a su lenguaje de programación, ej. `solution.c`, `solution.cpp` o `Solution.java`. Puede aprovechar el programa `px` incluido en el `.zip` que extrajo para el problema inventado. El comando `px` está diseñado para Bash, y por tanto, la línea de comandos de Linux. `px` le ayuda a compilar y probar su solución de la forma:

	./px               # Compila su solución
	./px test          # Prueba su solución contra todos los casos de prueba

 Por ejemplo, la siguiente ejecución indica que la solución *no* pasa el caso de prueba 3, porque produce el texto `0.00` pero se esperaba `invalid data`:

	./px test
	./solution < input001.txt > /tmp/px.diff && icdiff -W --no-headers /tmp/px.diff output001.txt
	./solution < input002.txt > /tmp/px.diff && icdiff -W --no-headers /tmp/px.diff output002.txt
	./solution < input003.txt > /tmp/px.diff && icdiff -W --no-headers /tmp/px.diff output003.txt
	0.00                                                                  invalid data
	./solution < input004.txt > /tmp/px.diff && icdiff -W --no-headers /tmp/px.diff output004.txt


## Casos de prueba autogenerados

Una vez que tenga su solución implementada, pueda que decida cambiar algo en el formato de salida de los casos de prueba existentes. En tal caso tendría que ajustar la salida de todos los casos de prueba que ya haya creado. También pueda ocurrir que quiera crear casos de prueba más extensos o complejos, pero su correspondiente salida es difícil de generar manualmente. En ambos casos puede usar su solución (en C, C++, Java) para actualizar o generar la salida esperada.

El comando `./px output` usa su solución para actualizar la salida de TODOS los casos de prueba. Debe tener mucho cuidado al invocar esta orden, dado que sobrescribirá los archivos `outputXXX.txt` con la salida de su programa. Es conveniente tener "commits" de estos archivos antes de emitir este comando, de tal forma que pueda revertir los cambios con Git en caso de algún problema en la solución.


## Presentar el problema inventado

Para presentar el problema al profesor haga los correspondientes "commits" y "push". Recuerde NO agregar ejecutables a su repositorio de control de versiones. Luego envíe un correo electrónico al profesor indicando el nombre de la carpeta del problema. El proceso continúa cuando el profesor discute el problema propuesto con el estudiante, sea de forma presencial, por correo electrónico, o aprovechando las herramientas de comunicación del sistema de control de versiones.
